# Gramex

[![Gramex on PyPi](https://badge.fury.io/py/gramex.svg)](https://badge.fury.io/py/gramex)

[Gramex](https://gramener.com/gramex/) is a low-code data platform: a fast way to build data-based web apps with less code.

Gramex takes a component based approach building data apps. (Like LEGO bricks.)
This needs fewer steps, takes less time, and builds apps with fewer bugs.

[Examples of public data apps built on Gramex](https://gramener.com/solutions/)

## Getting Started

- [Online Documentation](https://gramener.com/gramex/guide/)
- [Set up Gramex](https://gramener.com/gramex/guide/install/)

## Contributing

- **Need help?** [Browse the issues](https://github.com/gramener/gramex/issues)
- **Want to report a bug or request a feature?** [Open an issue](https://github.com/gramener/gramex/issues/new).
- **Want to fix a bug or add a feature?** [Read the contributing guidelines](https://gramener.com/gramex/guide/contributing/).
  Fork this repo, make changes, test it, and send a pull request.

## License

[MIT LICENSE](https://opensource.org/licenses/MIT)

Gramener also offers a Gramex Enterprise Server with support, security &
enterprise deployment. Contact license@gramener.com for details.
